@@ -221,24 +221,24 @@ rc_copula_log_lik <-function(p, x1, x2,indata1,indata2, quantiles = NULL, copula
   }
 
   term1 <- ifelse((indata1[,"status"] == 0) & (indata2[,"status"] == 0), C_val, 1)
-  term1 <- log(term1)
+  term1 <- log(abs(term1))
 
   term2 <- c_u1_val * (-u1_t1)
   term2 <- ifelse((indata1[,"status"] == 1) & (indata2[,"status"] == 0), term2, 1)
-  term2 <- log(term2)
+  term2 <- log(abs(term2))
   # term2 <- log(c_u1_val)+log(-u1_t1)
   # term2 <- ifelse((indata1[,"status"] == 1) & (indata2[,"status"] == 0), term2, 0)
 
   term3 <- (c_u2_val) * (-u2_t2)
   term3 <- ifelse((indata1[,"status"] == 0) & (indata2[,"status"] == 1), term3, 1)
-  term3 <- log(term3)
+  term3 <- log(abs(term3))
   # term3 <- log(c_u2_val)+log(-u2_t2)
   # term3 <- ifelse((indata1[,"status"] == 0) & (indata2[,"status"] == 1), term3, 0)
 
   term4 <- c_val * u1_t1 * u2_t2
   term4 <- ifelse((indata1[,"status"] == 1) & (indata2[,"status"] == 1), term4, 1)
   term4[term4 < 0] <- 1
-  term4 <- log(term4)
+  term4 <- log(abs(term4))
   # term4 <- log(c_val)+log(-u1_t1)+log(-u2_t2)
   # term4 <- ifelse((indata1[,"status"] == 1) & (indata2[,"status"] == 1), term4, 0)
 
@@ -352,19 +352,20 @@ ic_copula_log_lik_sieve <- function(para, p, m, x1, x2, bl1, br1, bl2, br2, inda
 
 
   # Use Copula functions to write each block of likelihood function
-  term1 <- log(C_val_1 - C_val_2 - C_val_3 + C_val_4)
+  term1 <- log(abs(C_val_1 - C_val_2 - C_val_3 + C_val_4))
   term1 <- ifelse((indata1[,"status"] == 1) & (indata2[,"status"] == 1), term1, 0)
 
-  term2 <- log(C_val_1 - C_val_3)
+  term2 <- log(abs(C_val_1 - C_val_3))
   term2 <- ifelse((indata1[,"status"] == 1) & (indata2[,"status"] == 0), term2, 0)
 
-  term3 <- log(C_val_1 - C_val_2)
+  term3 <- log(abs(C_val_1 - C_val_2))
   term3 <- ifelse((indata1[,"status"] == 0) & (indata2[,"status"] == 1), term3, 0)
 
-  term4 <- log(C_val_1)
+  term4 <- log(abs(C_val_1))
   term4 <- ifelse((indata1[,"status"] == 0) & (indata2[,"status"] == 0), term4, 0)
 
   logL<-(-1)*sum( term1 + term2 + term3 + term4 )
+
   return(logL)
 
 }
@@ -543,16 +544,16 @@ ic_copula_log_lik_param <- function(para, p, x1, x2, t1_left, t1_right, t2_left,
 
 
   # Use Copula functions to write each block of likelihood function
-  term1 <- log(C_val_1 - C_val_2 - C_val_3 + C_val_4)
+  term1 <- log(abs(C_val_1 - C_val_2 - C_val_3 + C_val_4))
   term1 <- ifelse((indata1[,"status"] == 1) & (indata2[,"status"] == 1), term1, 0)
 
-  term2 <- log(C_val_1 - C_val_3)
+  term2 <- log(abs(C_val_1 - C_val_3))
   term2 <- ifelse((indata1[,"status"] == 1) & (indata2[,"status"] == 0), term2, 0)
 
-  term3 <- log(C_val_1 - C_val_2)
+  term3 <- log(abs(C_val_1 - C_val_2))
   term3 <- ifelse((indata1[,"status"] == 0) & (indata2[,"status"] == 1), term3, 0)
 
-  term4 <- log(C_val_1)
+  term4 <- log(abs(C_val_1))
   term4 <- ifelse((indata1[,"status"] == 0) & (indata2[,"status"] == 0), term4, 0)
 
   logL<-(-1)*sum( term1 + term2 + term3 + term4 )
@@ -586,18 +587,19 @@ estimate_sieve_step1a <- function(para, p, m, x1, x2, bl1, br1, bl2, br2, indata
   C_val_3 <- u1_right*u2_left
   C_val_4 <- u1_right*u2_right
 
-  term1 <- log(C_val_1 - C_val_2 - C_val_3 + C_val_4)
+  term1 <- log(abs(C_val_1 - C_val_2 - C_val_3 + C_val_4))
   term1 <- ifelse((indata1[,"status"] == 1) & (indata2[,"status"] == 1), term1, 0)
 
-  term2 <- log(C_val_1 - C_val_3)
+  term2 <- log(abs(C_val_1 - C_val_3))
   term2 <- ifelse((indata1[,"status"] == 1) & (indata2[,"status"] == 0), term2, 0)
 
-  term3 <- log(C_val_1 - C_val_2)
+  term3 <- log(abs(C_val_1 - C_val_2))
   term3 <- ifelse((indata1[,"status"] == 0) & (indata2[,"status"] == 1), term3, 0)
 
-  term4 <- log(C_val_1)
+  term4 <- log(abs(C_val_1))
   term4 <- ifelse((indata1[,"status"] == 0) & (indata2[,"status"] == 0), term4, 0)
 
+
   logL <- (-1)*sum( term1 + term2 + term3 + term4 )
 
 
